==> istio-model-v1beta1-6.3.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/TrafficPolicyFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;

 /**
  * Generated
  */
public interface TrafficPolicyFluent<A extends TrafficPolicyFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildConnectionPool instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConnectionPoolSettings getConnectionPool();
  public ConnectionPoolSettings buildConnectionPool();
  public A withConnectionPool(ConnectionPoolSettings connectionPool);
  public Boolean hasConnectionPool();
  public TrafficPolicyFluent.ConnectionPoolNested<A> withNewConnectionPool();
  public TrafficPolicyFluent.ConnectionPoolNested<A> withNewConnectionPoolLike(ConnectionPoolSettings item);
  public TrafficPolicyFluent.ConnectionPoolNested<A> editConnectionPool();
  public TrafficPolicyFluent.ConnectionPoolNested<A> editOrNewConnectionPool();
  public TrafficPolicyFluent.ConnectionPoolNested<A> editOrNewConnectionPoolLike(ConnectionPoolSettings item);
  
  /**
   * This method has been deprecated, please use method buildLoadBalancer instead.
   * @return The buildable object.
   */
  @Deprecated
  public LoadBalancerSettings getLoadBalancer();
  public LoadBalancerSettings buildLoadBalancer();
  public A withLoadBalancer(LoadBalancerSettings loadBalancer);
  public Boolean hasLoadBalancer();
  public TrafficPolicyFluent.LoadBalancerNested<A> withNewLoadBalancer();
  public TrafficPolicyFluent.LoadBalancerNested<A> withNewLoadBalancerLike(LoadBalancerSettings item);
  public TrafficPolicyFluent.LoadBalancerNested<A> editLoadBalancer();
  public TrafficPolicyFluent.LoadBalancerNested<A> editOrNewLoadBalancer();
  public TrafficPolicyFluent.LoadBalancerNested<A> editOrNewLoadBalancerLike(LoadBalancerSettings item);
  
  /**
   * This method has been deprecated, please use method buildOutlierDetection instead.
   * @return The buildable object.
   */
  @Deprecated
  public OutlierDetection getOutlierDetection();
  public OutlierDetection buildOutlierDetection();
  public A withOutlierDetection(OutlierDetection outlierDetection);
  public Boolean hasOutlierDetection();
  public TrafficPolicyFluent.OutlierDetectionNested<A> withNewOutlierDetection();
  public TrafficPolicyFluent.OutlierDetectionNested<A> withNewOutlierDetectionLike(OutlierDetection item);
  public TrafficPolicyFluent.OutlierDetectionNested<A> editOutlierDetection();
  public TrafficPolicyFluent.OutlierDetectionNested<A> editOrNewOutlierDetection();
  public TrafficPolicyFluent.OutlierDetectionNested<A> editOrNewOutlierDetectionLike(OutlierDetection item);
  public A addToPortLevelSettings(Integer index,TrafficPolicyPortTrafficPolicy item);
  public A setToPortLevelSettings(Integer index,TrafficPolicyPortTrafficPolicy item);
  public A addToPortLevelSettings(io.fabric8.istio.api.networking.v1beta1.TrafficPolicyPortTrafficPolicy... items);
  public A addAllToPortLevelSettings(Collection<TrafficPolicyPortTrafficPolicy> items);
  public A removeFromPortLevelSettings(io.fabric8.istio.api.networking.v1beta1.TrafficPolicyPortTrafficPolicy... items);
  public A removeAllFromPortLevelSettings(Collection<TrafficPolicyPortTrafficPolicy> items);
  public A removeMatchingFromPortLevelSettings(Predicate<TrafficPolicyPortTrafficPolicyBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPortLevelSettings instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TrafficPolicyPortTrafficPolicy> getPortLevelSettings();
  public List<TrafficPolicyPortTrafficPolicy> buildPortLevelSettings();
  public TrafficPolicyPortTrafficPolicy buildPortLevelSetting(Integer index);
  public TrafficPolicyPortTrafficPolicy buildFirstPortLevelSetting();
  public TrafficPolicyPortTrafficPolicy buildLastPortLevelSetting();
  public TrafficPolicyPortTrafficPolicy buildMatchingPortLevelSetting(Predicate<TrafficPolicyPortTrafficPolicyBuilder> predicate);
  public Boolean hasMatchingPortLevelSetting(Predicate<TrafficPolicyPortTrafficPolicyBuilder> predicate);
  public A withPortLevelSettings(List<TrafficPolicyPortTrafficPolicy> portLevelSettings);
  public A withPortLevelSettings(io.fabric8.istio.api.networking.v1beta1.TrafficPolicyPortTrafficPolicy... portLevelSettings);
  public Boolean hasPortLevelSettings();
  public TrafficPolicyFluent.PortLevelSettingsNested<A> addNewPortLevelSetting();
  public TrafficPolicyFluent.PortLevelSettingsNested<A> addNewPortLevelSettingLike(TrafficPolicyPortTrafficPolicy item);
  public TrafficPolicyFluent.PortLevelSettingsNested<A> setNewPortLevelSettingLike(Integer index,TrafficPolicyPortTrafficPolicy item);
  public TrafficPolicyFluent.PortLevelSettingsNested<A> editPortLevelSetting(Integer index);
  public TrafficPolicyFluent.PortLevelSettingsNested<A> editFirstPortLevelSetting();
  public TrafficPolicyFluent.PortLevelSettingsNested<A> editLastPortLevelSetting();
  public TrafficPolicyFluent.PortLevelSettingsNested<A> editMatchingPortLevelSetting(Predicate<TrafficPolicyPortTrafficPolicyBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTls instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClientTLSSettings getTls();
  public ClientTLSSettings buildTls();
  public A withTls(ClientTLSSettings tls);
  public Boolean hasTls();
  public TrafficPolicyFluent.TlsNested<A> withNewTls();
  public TrafficPolicyFluent.TlsNested<A> withNewTlsLike(ClientTLSSettings item);
  public TrafficPolicyFluent.TlsNested<A> editTls();
  public TrafficPolicyFluent.TlsNested<A> editOrNewTls();
  public TrafficPolicyFluent.TlsNested<A> editOrNewTlsLike(ClientTLSSettings item);
  public interface ConnectionPoolNested<N> extends Nested<N>,ConnectionPoolSettingsFluent<TrafficPolicyFluent.ConnectionPoolNested<N>>{
    public N and();
    public N endConnectionPool();
    
  }
  public interface LoadBalancerNested<N> extends Nested<N>,LoadBalancerSettingsFluent<TrafficPolicyFluent.LoadBalancerNested<N>>{
    public N and();
    public N endLoadBalancer();
    
  }
  public interface OutlierDetectionNested<N> extends Nested<N>,OutlierDetectionFluent<TrafficPolicyFluent.OutlierDetectionNested<N>>{
    public N and();
    public N endOutlierDetection();
    
  }
  public interface PortLevelSettingsNested<N> extends Nested<N>,TrafficPolicyPortTrafficPolicyFluent<TrafficPolicyFluent.PortLevelSettingsNested<N>>{
    public N and();
    public N endPortLevelSetting();
    
  }
  public interface TlsNested<N> extends Nested<N>,ClientTLSSettingsFluent<TrafficPolicyFluent.TlsNested<N>>{
    public N and();
    public N endTls();
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/TrafficPolicyFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;

 /**
  * Generated
  */
public interface TrafficPolicyFluent<A extends TrafficPolicyFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildConnectionPool instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConnectionPoolSettings getConnectionPool();
  public ConnectionPoolSettings buildConnectionPool();
  public A withConnectionPool(ConnectionPoolSettings connectionPool);
  public Boolean hasConnectionPool();
  public TrafficPolicyFluent.ConnectionPoolNested<A> withNewConnectionPool();
  public TrafficPolicyFluent.ConnectionPoolNested<A> withNewConnectionPoolLike(ConnectionPoolSettings item);
  public TrafficPolicyFluent.ConnectionPoolNested<A> editConnectionPool();
  public TrafficPolicyFluent.ConnectionPoolNested<A> editOrNewConnectionPool();
  public TrafficPolicyFluent.ConnectionPoolNested<A> editOrNewConnectionPoolLike(ConnectionPoolSettings item);
  
  /**
   * This method has been deprecated, please use method buildLoadBalancer instead.
   * @return The buildable object.
   */
  @Deprecated
  public LoadBalancerSettings getLoadBalancer();
  public LoadBalancerSettings buildLoadBalancer();
  public A withLoadBalancer(LoadBalancerSettings loadBalancer);
  public Boolean hasLoadBalancer();
  public TrafficPolicyFluent.LoadBalancerNested<A> withNewLoadBalancer();
  public TrafficPolicyFluent.LoadBalancerNested<A> withNewLoadBalancerLike(LoadBalancerSettings item);
  public TrafficPolicyFluent.LoadBalancerNested<A> editLoadBalancer();
  public TrafficPolicyFluent.LoadBalancerNested<A> editOrNewLoadBalancer();
  public TrafficPolicyFluent.LoadBalancerNested<A> editOrNewLoadBalancerLike(LoadBalancerSettings item);
  
  /**
   * This method has been deprecated, please use method buildOutlierDetection instead.
   * @return The buildable object.
   */
  @Deprecated
  public OutlierDetection getOutlierDetection();
  public OutlierDetection buildOutlierDetection();
  public A withOutlierDetection(OutlierDetection outlierDetection);
  public Boolean hasOutlierDetection();
  public TrafficPolicyFluent.OutlierDetectionNested<A> withNewOutlierDetection();
  public TrafficPolicyFluent.OutlierDetectionNested<A> withNewOutlierDetectionLike(OutlierDetection item);
  public TrafficPolicyFluent.OutlierDetectionNested<A> editOutlierDetection();
  public TrafficPolicyFluent.OutlierDetectionNested<A> editOrNewOutlierDetection();
  public TrafficPolicyFluent.OutlierDetectionNested<A> editOrNewOutlierDetectionLike(OutlierDetection item);
  public A addToPortLevelSettings(int index,TrafficPolicyPortTrafficPolicy item);
  public A setToPortLevelSettings(int index,TrafficPolicyPortTrafficPolicy item);
  public A addToPortLevelSettings(io.fabric8.istio.api.networking.v1beta1.TrafficPolicyPortTrafficPolicy... items);
  public A addAllToPortLevelSettings(Collection<TrafficPolicyPortTrafficPolicy> items);
  public A removeFromPortLevelSettings(io.fabric8.istio.api.networking.v1beta1.TrafficPolicyPortTrafficPolicy... items);
  public A removeAllFromPortLevelSettings(Collection<TrafficPolicyPortTrafficPolicy> items);
  public A removeMatchingFromPortLevelSettings(Predicate<TrafficPolicyPortTrafficPolicyBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPortLevelSettings instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TrafficPolicyPortTrafficPolicy> getPortLevelSettings();
  public List<TrafficPolicyPortTrafficPolicy> buildPortLevelSettings();
  public TrafficPolicyPortTrafficPolicy buildPortLevelSetting(int index);
  public TrafficPolicyPortTrafficPolicy buildFirstPortLevelSetting();
  public TrafficPolicyPortTrafficPolicy buildLastPortLevelSetting();
  public TrafficPolicyPortTrafficPolicy buildMatchingPortLevelSetting(Predicate<TrafficPolicyPortTrafficPolicyBuilder> predicate);
  public Boolean hasMatchingPortLevelSetting(Predicate<TrafficPolicyPortTrafficPolicyBuilder> predicate);
  public A withPortLevelSettings(List<TrafficPolicyPortTrafficPolicy> portLevelSettings);
  public A withPortLevelSettings(io.fabric8.istio.api.networking.v1beta1.TrafficPolicyPortTrafficPolicy... portLevelSettings);
  public Boolean hasPortLevelSettings();
  public TrafficPolicyFluent.PortLevelSettingsNested<A> addNewPortLevelSetting();
  public TrafficPolicyFluent.PortLevelSettingsNested<A> addNewPortLevelSettingLike(TrafficPolicyPortTrafficPolicy item);
  public TrafficPolicyFluent.PortLevelSettingsNested<A> setNewPortLevelSettingLike(int index,TrafficPolicyPortTrafficPolicy item);
  public TrafficPolicyFluent.PortLevelSettingsNested<A> editPortLevelSetting(int index);
  public TrafficPolicyFluent.PortLevelSettingsNested<A> editFirstPortLevelSetting();
  public TrafficPolicyFluent.PortLevelSettingsNested<A> editLastPortLevelSetting();
  public TrafficPolicyFluent.PortLevelSettingsNested<A> editMatchingPortLevelSetting(Predicate<TrafficPolicyPortTrafficPolicyBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTls instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClientTLSSettings getTls();
  public ClientTLSSettings buildTls();
  public A withTls(ClientTLSSettings tls);
  public Boolean hasTls();
  public TrafficPolicyFluent.TlsNested<A> withNewTls();
  public TrafficPolicyFluent.TlsNested<A> withNewTlsLike(ClientTLSSettings item);
  public TrafficPolicyFluent.TlsNested<A> editTls();
  public TrafficPolicyFluent.TlsNested<A> editOrNewTls();
  public TrafficPolicyFluent.TlsNested<A> editOrNewTlsLike(ClientTLSSettings item);
  public interface ConnectionPoolNested<N> extends Nested<N>,ConnectionPoolSettingsFluent<TrafficPolicyFluent.ConnectionPoolNested<N>>{
    public N and();
    public N endConnectionPool();
    
  }
  public interface LoadBalancerNested<N> extends Nested<N>,LoadBalancerSettingsFluent<TrafficPolicyFluent.LoadBalancerNested<N>>{
    public N and();
    public N endLoadBalancer();
    
  }
  public interface OutlierDetectionNested<N> extends Nested<N>,OutlierDetectionFluent<TrafficPolicyFluent.OutlierDetectionNested<N>>{
    public N and();
    public N endOutlierDetection();
    
  }
  public interface PortLevelSettingsNested<N> extends Nested<N>,TrafficPolicyPortTrafficPolicyFluent<TrafficPolicyFluent.PortLevelSettingsNested<N>>{
    public N and();
    public N endPortLevelSetting();
    
  }
  public interface TlsNested<N> extends Nested<N>,ClientTLSSettingsFluent<TrafficPolicyFluent.TlsNested<N>>{
    public N and();
    public N endTls();
    
  }
  
}
